/*
    Help screen displayed on console while invoking zBoy from console mode with --help.
    This file is part of the zBoy project.
    Copyright (C) Mateusz Viste 2010,2011,2012,2013,2014
*/

#include <stdio.h>

void printhelp() {
  printf("\n");
  printf("      * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\n");
  printf("      *                                                                 *\n");
  printf("      *  zBoy - a full-featured GameBoy emulator for Linux and Windows  *\n");
  printf("      *    Copyright (C) Mateusz Viste 2010, 2011, 2012, 2013, 2014     *\n");
  printf("      *                                                                 *\n");
  printf("      * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\n");
  printf("\n");
  printf("+----------------------------------------------------------------------------+\n");
  printf("| Available keys:                                                            |\n");
  printf("|                                                                            |\n");
  printf("| Joypad actions | Keys mapping (on default keyboard mapping)                |\n");
  printf("|  UP            | Up arrow                                                  |\n");
  printf("|  DOWN          | Down arrow                                                |\n");
  printf("|  LEFT          | Left arrow                                                |\n");
  printf("|  RIGHT         | Right arrow                                               |\n");
  printf("|  START         | Enter (return)                                            |\n");
  printf("|  SELECT        | TAB                                                       |\n");
  printf("|  Button A      | CTRL                                                      |\n");
  printf("|  Button B      | ALT                                                       |\n");
  printf("|                                                                            |\n");
  printf("| Emulator's functions (using default keys assignements:                     |\n");
  printf("|  F1  - enables/disables game's background                                  |\n");
  printf("|  F2  - enables/disables game's sprites                                     |\n");
  printf("|  F3  - enables/disables game's window                                      |\n");
  printf("|  F5  - saves the current state of the game on disk (a.k.a. \"QuickSave\")    |\n");
  printf("|  F7  - loads the saved state of the game from disk (a.k.a. \"QuickLoad\")    |\n");
  printf("|  F8  - enables/disables autoscreenshot (does a screenshot every 10 seconds)|\n");
  printf("|  F9  - performs a PCX screenshot (snapshot saved to current directory)     |\n");
  printf("|  F10 - resets the CPU (restarts the game)                                  |\n");
  printf("|  ESC - quits the emulator                                                  |\n");
  printf("+----------------------------------------------------------------------------+\n");
  printf("\n");
  printf("+----------------------------------------------------------------------------+\n");
  printf("| Command-line usage:                                                        |\n");
  printf("|  zboy [--option1 --option2 ...] file.gb                                    |\n");
  printf("|                                                                            |\n");
  printf("| Available options:                                                         |\n");
  printf("|  --bootlogo      Boots over the Gameboy's internal ROM (which displays a   |\n");
  printf("|                  Nintendo logo), before executing the cartridge ROM.       |\n");
  printf("|  --[no]colorization  Activates or disables colorization. When enabled,     |\n");
  printf("|                  zBoy will colorize some games using special palettes.     |\n");
  printf("|  --eaglescale x  Scales the video screen x times using the EAGLE scaling   |\n");
  printf("|                  algorithm. Possible values are 2, 4, 6 or 8.              |\n");
  printf("|  --fpslimit x    Limit the FPS rendering to x frames per second. x must be |\n");
  printf("|                  in the range 1..60 (defaults to 60 FPS). This option will |\n");
  printf("|                  give odd results when combined with --nospeedlimit.       |\n");
  printf("|  --scale x       Scales the video screen x times. Possible values are      |\n");
  printf("|                  1..8 (defaults to 4 = 640x576).                           |\n");
  printf("|  --scale2x x     Scales the video screen x times using the Scale2x         |\n");
  printf("|                  algorithm. Possible values are 2, 4, 6 or 8.              |\n");
  printf("|  --scale3x x     Scales the video screen x times using the Scale3x         |\n");
  printf("|                  algorithm. Possible values are 3 or 6.                    |\n");
  printf("|  --palette name  Use an alternative palette of colors. Possible palettes   |\n");
  printf("|                  are: gbmicro or peasoup. The default one is gbmicro.      |\n");
  printf("|  --input keys    Redefine keys used to emulate the GameBoy's joypad. Need  |\n");
  printf("|                  to be followed by the list of scancodes in this exact     |\n");
  printf("|                  order: Up Down Left Right Start Select A B TurboA TurboB  |\n");
  printf("|                  See the list of available scancodes below.                |\n");
  printf("|  --fnkeys keys   Redefine keys used for calling functions of the emulator. |\n");
  printf("|                  Need to be followed by the list of scancodes in this exact|\n");
  printf("|                  order: bgCtrl spriteCtrl windowCtrl Save Load Autoshot    |\n");
  printf("|                  Screenshot Reset Quit                                     |\n");
  printf("|                  See the list of available scancodes below.                |\n");
  printf("|  --nocpuidle     Do not try to idle the CPU when the emulator have some    |\n");
  printf("|                  spare time. This might give better results on hi-latency  |\n");
  printf("|                  systems, at the cost of using the CPU at full speed.      |\n");
  printf("|  --nospeedlimit  Runs zBoy at full (unlimited) speed. This is not a good   |\n");
  printf("|                  idea if you want to play games, but might be useful for   |\n");
  printf("|                  some benchmarking needs.                                  |\n");
  printf("|  --showfps       Shows the FPS counter (frames per second) in the title    |\n");
  printf("|                  bar of zBoy's window.                                     |\n");
  printf("|  --noscreensaver Prohibits any screen saver to start while the emulator is |\n");
  printf("|                  running.                                                  |\n");
  printf("|  --hiscoresmem   This option will tell zBoy to memorize HiScores in games  |\n");
  printf("|                  that aren't able to do so by themselves (eg. Pipe Dream). |\n");
  printf("|  --rominfos      Displays various informations about the ROM before start. |\n");
  printf("|  --netplay x     Establish a 2 player session mode with the IP 'x'.        |\n");
  printf("|  --bindaddr x    In case of using --netplay, the --bindaddr parameter      |\n");
  printf("|                  allows to force the local IP (automatic by default).      |\n");
  printf("+----------------------------------------------------------------------------+\n");
  printf("\n");
  printf("+----------------------------------------------------------------------------+\n");
  printf("| List of available scancodes (useable with --input or --fnkeys)             |\n");
  printf("|                                                                            |\n");
  printf("| zBoy's key name | Description                                              |\n");
  printf("| ----------------+------------------------------                            |\n");
  printf("|    kb.f1        | F1 key                                                   |\n");
  printf("|    kb.f2        | F2 key                                                   |\n");
  printf("|    kb.f3        | F3 key                                                   |\n");
  printf("|    kb.f4        | F4 key                                                   |\n");
  printf("|    kb.f5        | F5 key                                                   |\n");
  printf("|    kb.f6        | F6 key                                                   |\n");
  printf("|    kb.f7        | F7 key                                                   |\n");
  printf("|    kb.f8        | F8 key                                                   |\n");
  printf("|    kb.f9        | F9 key                                                   |\n");
  printf("|    kb.f10       | F10 key                                                  |\n");
  printf("|    kb.f11       | F11 key                                                  |\n");
  printf("|    kb.f12       | F12 key                                                  |\n");
  printf("|    kb.esc       | Escape key                                               |\n");
  printf("|    kb.tab       | TAB                                                      |\n");
  printf("|    kb.lctrl     | Left control key                                         |\n");
  printf("|    kb.lalt      | Left ALT key                                             |\n");
  printf("|    kb.rctrl     | Right control key                                        |\n");
  printf("|    kb.ralt      | Right ALT key                                            |\n");
  printf("|    kb.spc       | Space                                                    |\n");
  printf("|    kb.ret       | Return (enter)                                           |\n");
  printf("|    kb.bks       | Backspace                                                |\n");
  printf("|    kb.left      | Left arrow                                               |\n");
  printf("|    kb.right     | Right arrow                                              |\n");
  printf("|    kb.up        | Up arrow                                                 |\n");
  printf("|    kb.down      | Down arrow                                               |\n");
  printf("|    kb.rshift    | Right shift key                                          |\n");
  printf("|    kb.lshift    | Left shift key                                           |\n");
  printf("|    kb.lwin      | Left \"Windows\" key                                       |\n");
  printf("|    kb.rwin      | Right \"Windows\" key                                      |\n");
  printf("|    kb.menu      | \"Menu\" key                                               |\n");
  printf("|    kb.pgup      | Page up                                                  |\n");
  printf("|    kb.pgdw      | Page down                                                |\n");
  printf("|    kb.home      | Home key                                                 |\n");
  printf("|    kb.end       | End key                                                  |\n");
  printf("|    kb.ins       | Insert key                                               |\n");
  printf("|    kb.del       | Delete key                                               |\n");
  printf("|    kb.a         | Key \"a\"                                                  |\n");
  printf("|    kb.b         | Key \"b\"                                                  |\n");
  printf("|    kb.c         | Key \"c\"                                                  |\n");
  printf("|    kb.d         | Key \"d\"                                                  |\n");
  printf("|    kb.e         | Key \"e\"                                                  |\n");
  printf("|    kb.f         | Key \"f\"                                                  |\n");
  printf("|    kb.g         | Key \"g\"                                                  |\n");
  printf("|    kb.h         | Key \"h\"                                                  |\n");
  printf("|    kb.i         | Key \"i\"                                                  |\n");
  printf("|    kb.j         | Key \"j\"                                                  |\n");
  printf("|    kb.k         | Key \"k\"                                                  |\n");
  printf("|    kb.l         | Key \"l\"                                                  |\n");
  printf("|    kb.m         | Key \"m\"                                                  |\n");
  printf("|    kb.n         | Key \"n\"                                                  |\n");
  printf("|    kb.o         | Key \"o\"                                                  |\n");
  printf("|    kb.p         | Key \"p\"                                                  |\n");
  printf("|    kb.q         | Key \"q\"                                                  |\n");
  printf("|    kb.r         | Key \"r\"                                                  |\n");
  printf("|    kb.s         | Key \"s\"                                                  |\n");
  printf("|    kb.t         | Key \"t\"                                                  |\n");
  printf("|    kb.u         | Key \"u\"                                                  |\n");
  printf("|    kb.v         | Key \"v\"                                                  |\n");
  printf("|    kb.w         | Key \"w\"                                                  |\n");
  printf("|    kb.x         | Key \"x\"                                                  |\n");
  printf("|    kb.y         | Key \"y\"                                                  |\n");
  printf("|    kb.z         | Key \"z\"                                                  |\n");
  printf("|    kb.0         | Key \"0\"                                                  |\n");
  printf("|    kb.1         | Key \"1\"                                                  |\n");
  printf("|    kb.2         | Key \"2\"                                                  |\n");
  printf("|    kb.3         | Key \"3\"                                                  |\n");
  printf("|    kb.4         | Key \"4\"                                                  |\n");
  printf("|    kb.5         | Key \"5\"                                                  |\n");
  printf("|    kb.6         | Key \"6\"                                                  |\n");
  printf("|    kb.7         | Key \"7\"                                                  |\n");
  printf("|    kb.8         | Key \"8\"                                                  |\n");
  printf("|    kb.9         | Key \"9\"                                                  |\n");
  printf("|    joy1.a1pos   | Axis #1 on joypad #1 (positive value of the axis)        |\n");
  printf("|    joy1.a1neg   | Axis #1 on joypad #1 (negative value of the axis)        |\n");
  printf("|    joy1.a2pos   | Axis #2 on joypad #1 (positive value of the axis)        |\n");
  printf("|    joy1.a2neg   | Axis #2 on joypad #1 (negative value of the axis)        |\n");
  printf("|    joy1.a3pos   | Axis #3 on joypad #1 (positive value of the axis)        |\n");
  printf("|    joy1.a3neg   | Axis #3 on joypad #1 (negative value of the axis)        |\n");
  printf("|    joy1.a4pos   | Axis #4 on joypad #1 (positive value of the axis)        |\n");
  printf("|    joy1.a4neg   | Axis #4 on joypad #1 (negative value of the axis)        |\n");
  printf("|    joy1.b1      | Button #1 on joypad #1                                   |\n");
  printf("|    joy1.b2      | Button #2 on joypad #1                                   |\n");
  printf("|    joy1.b3      | Button #3 on joypad #1                                   |\n");
  printf("|    joy1.b4      | Button #4 on joypad #1                                   |\n");
  printf("|    joy1.b5      | Button #5 on joypad #1                                   |\n");
  printf("|    joy1.b6      | Button #6 on joypad #1                                   |\n");
  printf("|    joy1.b7      | Button #7 on joypad #1                                   |\n");
  printf("|    joy1.b8      | Button #8 on joypad #1                                   |\n");
  printf("|    joy1.b9      | Button #9 on joypad #1                                   |\n");
  printf("|    joy1.b10     | Button #10 on joypad #1                                  |\n");
  printf("|    joy1.b11     | Button #11 on joypad #1                                  |\n");
  printf("|    joy1.b12     | Button #12 on joypad #1                                  |\n");
  printf("|    joy1.b13     | Button #13 on joypad #1                                  |\n");
  printf("|    joy1.b14     | Button #14 on joypad #1                                  |\n");
  printf("|    joy1.b15     | Button #15 on joypad #1                                  |\n");
  printf("|    joy1.b16     | Button #16 on joypad #1                                  |\n");
  printf("|    joy2.a1pos   | Axis #1 on joypad #2 (positive value of the axis)        |\n");
  printf("|    joy2.a1neg   | Axis #1 on joypad #2 (negative value of the axis)        |\n");
  printf("|    joy2.a2pos   | Axis #2 on joypad #2 (positive value of the axis)        |\n");
  printf("|    joy2.a2neg   | Axis #2 on joypad #2 (negative value of the axis)        |\n");
  printf("|    joy2.a3pos   | Axis #3 on joypad #2 (positive value of the axis)        |\n");
  printf("|    joy2.a3neg   | Axis #3 on joypad #2 (negative value of the axis)        |\n");
  printf("|    joy2.a4pos   | Axis #4 on joypad #2 (positive value of the axis)        |\n");
  printf("|    joy2.a4neg   | Axis #4 on joypad #2 (negative value of the axis)        |\n");
  printf("|    joy2.b1      | Button #1 on joypad #2                                   |\n");
  printf("|    joy2.b2      | Button #2 on joypad #2                                   |\n");
  printf("|    joy2.b3      | Button #3 on joypad #2                                   |\n");
  printf("|    joy2.b4      | Button #4 on joypad #2                                   |\n");
  printf("|    joy2.b5      | Button #5 on joypad #2                                   |\n");
  printf("|    joy2.b6      | Button #6 on joypad #2                                   |\n");
  printf("|    joy2.b7      | Button #7 on joypad #2                                   |\n");
  printf("|    joy2.b8      | Button #8 on joypad #2                                   |\n");
  printf("|    joy2.b9      | Button #9 on joypad #2                                   |\n");
  printf("|    joy2.b10     | Button #10 on joypad #2                                  |\n");
  printf("|    joy2.b11     | Button #11 on joypad #2                                  |\n");
  printf("|    joy2.b12     | Button #12 on joypad #2                                  |\n");
  printf("|    joy2.b13     | Button #13 on joypad #2                                  |\n");
  printf("|    joy2.b14     | Button #14 on joypad #2                                  |\n");
  printf("|    joy2.b15     | Button #15 on joypad #2                                  |\n");
  printf("|    joy2.b16     | Button #16 on joypad #2                                  |\n");
  printf("|    none         | No key assigned (useful if we don't need some keys)      |\n");
  printf("|                                                                            |\n");
  printf("+----------------------------------------------------------------------------+\n");
  printf("                 homepage: http://zboy.sourceforge.net/\n");
  printf("\n");
}
